Castle class

Constructors

Castle()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

createRequestToken → Future<String?>
no setter
requestTokenHeaderName → Future<String?>
no setter

Static Methods

advertisingIdentifier(String identifier) → Future<void>
configure({required dynamic publishableKey, dynamic debugLoggingEnabled, dynamic maxQueueLimit, dynamic flushLimit, dynamic baseURLAllowList, dynamic lifeCycleEventsEnabled, dynamic touchCollectionEnabled}) → Future<void>
touchCollectionEnabled is iOS only and has no effect on Android.
custom(String name, Map<String, dynamic>? properties) → Future<void>
flush() → Future<void>
reset() → Future<void>
screen(String name) → Future<void>
userJwt(String userJwt) → Future<void>